Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/sparc64/dev sparc64/zs(4): Convert to ttylock/ttyun...



details:   https://anonhg.NetBSD.org/src/rev/00fc80cadafe
branches:  trunk
changeset: 372104:00fc80cadafe
user:      riastradh <riastradh%NetBSD.org@localhost>
date:      Wed Oct 26 23:59:56 2022 +0000

description:
sparc64/zs(4): Convert to ttylock/ttyunlock.

diffstat:

 sys/arch/sparc64/dev/zs.c |  10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)

diffs (38 lines):

diff -r 8c700d5bf187 -r 00fc80cadafe sys/arch/sparc64/dev/zs.c
--- a/sys/arch/sparc64/dev/zs.c Wed Oct 26 23:59:36 2022 +0000
+++ b/sys/arch/sparc64/dev/zs.c Wed Oct 26 23:59:56 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: zs.c,v 1.79 2022/10/26 23:38:08 riastradh Exp $        */
+/*     $NetBSD: zs.c,v 1.80 2022/10/26 23:59:56 riastradh Exp $        */
 
 /*-
  * Copyright (c) 1996 The NetBSD Foundation, Inc.
@@ -38,7 +38,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: zs.c,v 1.79 2022/10/26 23:38:08 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: zs.c,v 1.80 2022/10/26 23:59:56 riastradh Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -541,8 +541,8 @@
        struct zsc_softc *zsc = arg;
 
 #if 0 /* not yet */
-       /* Make sure we call the tty layer with tty_lock held. */
-       mutex_spin_enter(&tty_lock);
+       /* Make sure we call the tty layer with ttylock held. */
+       ttylock(tp);
 #endif
        (void)zsc_intr_soft(zsc);
 #ifdef TTY_DEBUG
@@ -558,7 +558,7 @@
        }
 #endif
 #if 0 /* not yet */
-       mutex_spin_exit(&tty_lock);
+       ttyunlock(tp);
 #endif
 }
 



Home | Main Index | Thread Index | Old Index